#!/bin/sh
#
# source: http://hal.freedesktop.org/releases/polkit-gnome-0.100.tar.bz2
#
# maintainer: jp
#

#------------------Set Some Variables

soft='polkit-gnome'
softversion='0.101'
packageversion='70.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
PKG="/tmp/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $PKG.tgz
rm -rf $PKG

#------------------Set correct permissions

cd $src

chown -R root:root .
find . \
  \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
  -exec chmod 755 {} \; -o \
  \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
  -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --enable-static=no \
  --disable-introspection

make -j2 || exit 1
make install DESTDIR=$PKG

find $PKG | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

find $PKG/usr/man -type f -exec gzip -9 {} \;

# We use XFCE
mkdir -p $PKG/etc/xdg/autostart
cp $buildir/polkit-gnome-authentication-agent-1.desktop $PKG/etc/xdg/autostart
# sed -i 's/OnlyShowIn=.*/OnlyShowIn=XFCE;GNOME;OPENBOX;/' $PKG/etc/xdg/autostart/polkit-gnome-authentication-agent-1.desktop

#-------------------Prepare the documentation

mkdir -p $PKG/usr/doc/$soft-$softversion
cp -a COPYING HACKING INSTALL NEWS $PKG/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $PKG/install
cat << EODESC > $PKG/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

            |-----handy-ruler-----------------------------------------------|
polkit-gnome: polkit-gnome - provides an Authentication Agent for polkit
polkit-gnome:
polkit-gnome: PolKit-gnome provides an Authentication Agent for polki that
polkit-gnome: integrates well with the GNOME desktop environment
polkit-gnome: 
polkit-gnome: 
polkit-gnome:
polkit-gnome:
polkit-gnome:
polkit-gnome:
polkit-gnome:
EODESC

mkdir -p $PKG/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $PKG/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $PKG
makepkg -l y -c n $PKG.txz
cd $buildir
rm -rf $PKG
